@@ -28,12 +28,24 @@ PaymentFundStatusesLiterals = Literal[
     'unknown'
 ]
 
+
 PaymentTypesLiterals = Literal[
     'standard',
     'clearing'
 ]
 
 
+PaymentFeeTypesLiterals = Literal[
+    'total',
+    'markup'
+]
+
+
+class PaymentFee(TypedDict):
+    type: PaymentFeeTypesLiterals
+    amount: int
+
+
 class Payment(TypedDict):
     id: str
     reversal_id: Optional[str]
@@ -48,6 +60,9 @@ class Payment(TypedDict):
     error: Optional[ResourceError]
     metadata: Optional[Dict[str, Any]]
     estimated_completion_date: Optional[str]
+    source_settlement_date: Optional[str]
+    destination_settlement_date: Optional[str]
+    fee: Optional[PaymentFee]
     type: PaymentTypesLiterals
     created_at: str
     updated_at: str
@@ -59,13 +74,14 @@ class PaymentCreateOpts(TypedDict):
     destination: str
     description: str
     metadata: Optional[Dict[str, Any]]
+    fee: Optional[PaymentFee]
 
 
 class PaymentListOpts(TypedDict):
     to_date: Optional[str]
     from_date: Optional[str]
-    page: Optional[str | int]
-    page_limit: Optional[str | int]
+    page: Optional[int]
+    page_limit: Optional[int]
     page_cursor: Optional[str]
     status: Optional[str]
     type: Optional[str]
